import os
import pprint
os.environ['LANG']='en_US.UTF-8'
import unittest
from bzv.customerConfig import CustomerConfig
from bzv.infra import Infra
import pprint
infra = None

class CustomerConfigTest(unittest.TestCase):
    # N.B. Tests are run in alphabetical order.
    #
    def makeInfra(self):
        global infra
        bzvConfigFile  = 'data/bzv.cfg'
        infra = Infra('Running customerConfigTest', bzvConfigFile=bzvConfigFile)
        infra.logging.error("minimal Infra logging")
        infra.logger.debug("logfile is correctly configured")
        # 'leen' de logger van infra
        # met randomwaarde wegschrijven naar syslog en weer teruglezen?

    def setUp(self):
        global infra
        if infra is None:
            print "make infra"
            self.makeInfra()
            
        self.configRoot = infra.configRoot 
        self.pp = pprint.PrettyPrinter(indent=2)

    def testGetExistingOption(self):
        foo = self.configRoot.get(option = 'foo', section='testSection')
        self.failUnless(foo == 'bar' )

    def testGetExistingOptionLanguage(self):
        foo = self.configRoot.get(option = 'foo', section='testSection', language='nl')
        self.failUnless(foo == 'barkruk' )

    def testGetNoneExistingOptionWithDefault(self):
        foo = self.configRoot.get(option = 'noneexistent', section = 'testSection',default = 'defaultvalue')
        self.failUnless(foo == 'defaultvalue' )

    def testGetNoneExistingOptionWithoutDefault(self):
        foo = self.configRoot.get(option = 'noneexistent', section ='testSection')
        self.failUnless(foo == 'noneexistent' )

    def testGetNoneExistingSection(self):
        foo = self.configRoot.get(option = 'defaultvalue', section='nonexistingSection')
        self.failUnless(foo == 'defaultvalue' )

    def testGetValueAsList(self):
        list = self.configRoot.getValueAsList(option = 'someList', section='anotherSection')
        self.failUnless(list[0] == 'foo' 
                    and list[1] == "bar" )

    def testGetValueAsListFrench(self):
        pp = pprint.PrettyPrinter(indent=2)
        list = self.configRoot.getValueAsList(option = 'someList', section='anotherSection', language='fr')
        self.failUnless(list[0] == 'fault' and list[1] == "bars" , "getValueAsListFrench Error: " + pp.pformat(list))

    def testGetSectionDict(self):
        pp = pprint.PrettyPrinter(indent=2)
        dct = self.configRoot.getSectionDict(section='dictSection')
        print pp.pformat(dct)
        self.failUnless(dct['a'] == 'bee' and dct['foo' ] == 'bar' ,"sectionDict Error: "+ pp.pformat(dct))

    def testMergeSectionDict(self):
        pp = pprint.PrettyPrinter(indent=2)
        dct = self.configRoot.getSectionDict(section='dictSection', mergeDict = {'x' : 'y'} )
        print pp.pformat(dct)

        self.failUnless(dct['a'] == 'bee' and dct['foo' ] == 'bar' and dct['x'] == 'y' 
                        ,"sectionDict Error: "+ pp.pformat(dct))

    def testGetSectionDictDutch(self):
        pp = pprint.PrettyPrinter(indent=2)
        dct = self.configRoot.getSectionDict(section='dictSection', language='nl')
        #print pp.pformat(dct)
        self.failUnless(dct['a'] == 'bij' and dct['foo' ] == 'bar' ,"sectionDict Error: "+ pp.pformat(dct))

    def testGetSectionTupleList(self):
        pp = pprint.PrettyPrinter(indent=2)
        list = sorted(self.configRoot.getSectionTupleList(section='dictSection'))
        infra.logger.debug(pp.pformat(list))
        (key,value) = list[0] 
        self.failUnless(key == 'a' and value == 'bee', 'testGetSectionTupleList fails!' )

    def testGetSectionTupleListDutch(self):
        pp = pprint.PrettyPrinter(indent=2)
        list = sorted(self.configRoot.getSectionTupleList(section='dictSection', language='nl'))
        print pp.pformat(list)
        (key,value) = list[0] 
        self.failUnless(key == 'a' and value == 'bij', 'testGetSectionTupleListDutch fails!' )

    def testConventialGet(self): 
        storageType = self.configRoot.get('storagetype', section = 'storagecomponent')
        self.failUnless(storageType in ['boushi','filesystem'] ,'onverwacht storagetype: "' + storageType +'"')

#    def testConfigFilename(self):
#        self.logger.debug('[storagecomponent] lives in: "' + self.configRoot.sections['storagecomponent']['filename'] +'"')
        #test?
        
    def testGetSectionNormalized(self):
        pp = pprint.PrettyPrinter(indent=2)
        d = self.configRoot.getSectionNormalized(section = 'language')
        infra.logger.debug('reverseDict: ' + self.pp.pformat(d))
        self.failUnless(d['af']  == 'afrikaans' and 
                        d['afr'] == 'afrikaans' and
                        d['ab']  == 'abkhazian' and
                        d['abk'] == 'abkhazian' and
                        d['ace'] == 'achinese', 'Normalisation failed') 

        self.failUnless(d['info:eu-repo/semantics/conferenceContribution']  == 'conference paper' and 
                        d['http://purl.org/eprint/type/ConferencePaper'] == 'conference paper',
                        'Normalisation failed: ' + pp.pformat(d)) 
        
        

if __name__ == '__main__':
    unittest.main()
